OATH-LDAP web applications
==========================

[OATH-LDAP](https://oath-ldap.stroeder.com/) directly integrates
OTP-based two-factor authentication into
[OpenLDAP](https://www.openldap.org) *slapd*.

This package implements the web applications:

  * Simple OATH enrollment web application

Requirements
------------

  * Python 3.6+
